@@ -40,12 +40,13 @@ A package string looks like: SECTION/NAME[:VERSION]
 For example: core/autoconf:2.69
 A package group string looks like: NAME
 For example: core, gnome, x11))"))
-(define license-message (_ "\
-Upmf 0.6
+(define license-message
+  (string-append "Upmf 0.6.1"
+		 (_ "\
 Copyright (C) 2013 Aljosha Papsch
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.
 This is free software: you are free to change and redistribute it.
-There is NO WARRANTY, to the extent permitted by law."))
+There is NO WARRANTY, to the extent permitted by law.")))
 
 ;; install-package adds a package string after successful installation
 ;; and install-handler displays these strings
@@ -91,12 +92,10 @@ There is NO WARRANTY, to the extent permitted by law."))
       (statusmsg (_ "Removing package") package-string)
       (if (access? dir-to-remove F_OK)
 	  (statusmsg (_ "Removing directory") dir-to-remove)
-	  (errormsg (string-append (_ "Release not installed: ") package-string)
-		    'fatal))
+	  (errormsg (_ "Release not installed") package-string 'fatal))
       (if (exec (string-append "rm -r " dir-to-remove))
 	  (statusmsg (_ "Package successfully removed") package-string)
-	  (errormsg (string-append (_ "Unable to remove directory: ")
-				   dir-to-remove) 'nofatal)))))
+	  (errormsg (_ "Unable to remove directory") dir-to-remove)))))
 
 (define print-release
   (lambda (release package-obj)
@@ -129,7 +128,7 @@ There is NO WARRANTY, to the extent permitted by law."))
     (statusmsg (_ "Successfully installed packages:"))
     (do ((k 0 (1+ k)))
 	((> k (- (length installed-packages) 1)))
-      (statusmg (_ "Package") (list-ref installed-packages k)))
+      (statusmsg (_ "Package") (list-ref installed-packages k)))
     (newline)))
 
 (define remove-handler
