@@ -66,8 +66,8 @@
 	  pfile
 	  (if (string=? (list-ref package-name 0) "unknown")
 	      (search-directories (list-ref package-name 1))
-	      (errormsg (string-append (_ "Package file not found for package: ")
-				       package-string) 'fatal))))))
+	      (errormsg (_ "Package file not found for package")
+			package-string 'fatal))))))
 
 ;; Find package NEEDLE
 ;; NEEDLE can be the name with or without the section.
