@@ -18,11 +18,16 @@
 ;;  along with Upmf.  If not, see <http://www.gnu.org/licenses/>.
 
 (define errormsg
-  (lambda (message fatal)
-    (display (string-append (list-ref (command-line) 0) ": " message))
-    (newline)
-    (if (eq? fatal 'fatal)
-	(quit))))
+  (lambda* (message #:optional append-str fatal)
+	   (if (eq? append-str #f)
+	       (begin (display (string-append (list-ref (command-line) 0)
+					      ": " message)))
+	       (begin (display (string-append (list-ref (command-line) 0)
+					      ": " message ": "
+					      append-str))))
+	   (newline)
+	   (if (eq? fatal 'fatal)
+	       (quit))))
 
 (define statusmsg
   (lambda* (message #:optional append-str)
@@ -48,12 +53,11 @@
     (if (exec (string-append "patch -d " directory
 			     " -Np1 " patch ".patch"))
 	(statusmsg (_ "Patch successfully applied."))
-	(errormsg (string-append (_ "Failed to apply patch: ") patch) 'fatal))))
+	(errormsg (_ "Failed to apply patch") patch 'fatal))))
 
 (define tar-extract
   (lambda (archive-file dest-dir)
     (statusmsg (_ "Extracting archive") archive-file)
     (if (exec (string-append "tar -xf " archive-file " -C " dest-dir))
 	(statusmsg (_ "Archive file successfully extracted."))
-	(errormsg (string-append (_ "Failed to extract archive: ")
-				 archive-file) 'fatal))))
+	(errormsg (_ "Failed to extract archive") archive-file 'fatal))))
